<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="131"/>
        <source>Actions:</source>
        <translation>Ebikolwa:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="155"/>
        <source>OK</source>
        <translation>Kale</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="274"/>
        <source>Clear All</source>
        <translation>Byerulewo byonna</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="285"/>
        <source>Do Not Disturb</source>
        <translation>Nkyakwataganye</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="293"/>
        <source>Options</source>
        <translation>Ebisoboka</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="300"/>
        <location filename="../notifyd.cpp" line="358"/>
        <location filename="../notifyd.cpp" line="379"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>Obubaka obutannakeberwa bwa murundi %n</numerusform>
            <numerusform>Obubaka obutannakeberwa bwa mirundi %n</numerusform>
        </translation>
    </message>
</context>
</TS>
